/*
 * Copyright (C) 2016 Robert F Cooper <rfcooper@sas.upenn.edu>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package mosaicanalytics.core.montage;

import java.awt.image.BufferedImage;
import java.awt.image.ComponentSampleModel;
import java.io.IOException;
import java.net.URISyntaxException;
import java.util.Iterator;
import javax.imageio.ImageIO;
import javax.imageio.ImageReader;
import javax.imageio.stream.ImageInputStream;
import static org.junit.Assert.assertEquals;
import org.junit.Test;

/**
 *
 * @author Robert F Cooper <rfcooper@sas.upenn.edu>
 */
public class PSDLayerReadTest {

    @Test
    public void testReadGrayscaleWithBkgrd() throws IOException, URISyntaxException {

        // Create input stream- if you integrate into PSDImageReaderTest.java, then you can use getClassLoaderResource("/psd/test_grayscale_boxes.psd")
        try (ImageInputStream stream = ImageIO.createImageInputStream( getClass().getResourceAsStream("/resources/psdreading/test_grayscale_boxes.psd") ) ) {
            
            Iterator<ImageReader> readerList = ImageIO.getImageReaders(stream);            
          
            ImageReader psdReader = readerList.next();
  
            psdReader.setInput(stream);

            int num_layers = psdReader.getNumImages(false);
            
            for(int i=0; i< num_layers; i++){
                
                BufferedImage layerImage = psdReader.read(i);
                
                int[] bands = ((ComponentSampleModel)layerImage.getRaster().getSampleModel()).getBankIndices();
                
                // The image bands should be read in sequence (0, 1, 2, etc) for a multi-channel layer.
                for(int j=0; j<bands.length; j++){
                    assertEquals( j, bands[j] );
                }
            }
        }
    }
}
